from PIL import ImageGrab
from pynput import mouse, keyboard
import time
import threading
import os

def take_screenshot():
    # 指定保存截图的目录
    save_dir = './screenshot/'
    # 如果目录不存在，则创建
    if not os.path.exists(save_dir):
        os.makedirs(save_dir)
        print(f"[{time.strftime('%Y-%m-%d %H:%M:%S')}] 目录 '{save_dir}' 已创建。")
    else:
        print(f"[{time.strftime('%Y-%m-%d %H:%M:%S')}] 目录 '{save_dir}' 已存在。")
    
    # 获取当前屏幕截图
    screenshot = ImageGrab.grab()
    
    # 生成易读的时间格式作为文件名
    timestamp = time.strftime("%Y-%m-%d_%H-%M-%S")
    filename = f"{save_dir}screenshot_{timestamp}.png"
    
    # 保存截图
    screenshot.save(filename, 'PNG')
    print(f"[{time.strftime('%Y-%m-%d %H:%M:%S')}] 截图已保存为 {filename}\n")
    
# 全局标志，用于控制程序运行
running = True

def on_click(x, y, button, pressed):
    if not running:
        # 停止鼠标监听器
        print(f"[{time.strftime('%Y-%m-%d %H:%M:%S')}] 鼠标监听器已停止。")
        return False
    # 检查是否是鼠标左键点击
    if button == mouse.Button.left and pressed:
        print(f"[{time.strftime('%Y-%m-%d %H:%M:%S')}] 鼠标左键按下在位置：({x}, {y})")
        take_screenshot()
    elif button == mouse.Button.left and not pressed:
        print(f"[{time.strftime('%Y-%m-%d %H:%M:%S')}] 鼠标左键释放在位置：({x}, {y})")
    else:
        print(f"[{time.strftime('%Y-%m-%d %H:%M:%S')}] 鼠标事件：{button}，状态：{'按下' if pressed else '释放'}，位置：({x}, {y})")

def on_press(key):
    global running
    try:
        # 检查是否按下了 Esc 键
        if key == keyboard.Key.esc:
            print(f"[{time.strftime('%Y-%m-%d %H:%M:%S')}] 检测到 Esc 键，程序即将退出...")
            running = False
            # 停止键盘监听器
            return False
        else:
            print(f"[{time.strftime('%Y-%m-%d %H:%M:%S')}] 按下键：{key}")
    except AttributeError:
        print(f"[{time.strftime('%Y-%m-%d %H:%M:%S')}] 按下特殊键：{key}")

def on_release(key):
    try:
        print(f"[{time.strftime('%Y-%m-%d %H:%M:%S')}] 释放键：{key}")
    except AttributeError:
        print(f"[{time.strftime('%Y-%m-%d %H:%M:%S')}] 释放特殊键：{key}")

def keyboard_listener():
    with keyboard.Listener(on_press=on_press, on_release=on_release) as listener:
        listener.join()
    print(f"[{time.strftime('%Y-%m-%d %H:%M:%S')}] 键盘监听器已停止。")

def mouse_listener():
    with mouse.Listener(on_click=on_click) as listener:
        listener.join()
    print(f"[{time.strftime('%Y-%m-%d %H:%M:%S')}] 鼠标监听器已停止。")

if __name__ == "__main__":
    print(f"[{time.strftime('%Y-%m-%d %H:%M:%S')}] 程序启动，按下鼠标左键进行截图，按下 Esc 键退出程序。")
    
    # 使用多线程同时运行鼠标和键盘监听器
    keyboard_thread = threading.Thread(target=keyboard_listener)
    mouse_thread = threading.Thread(target=mouse_listener)
    
    keyboard_thread.start()
    mouse_thread.start()
    
    keyboard_thread.join()
    mouse_thread.join()
    
    print(f"[{time.strftime('%Y-%m-%d %H:%M:%S')}] 程序已退出。")
